@@ -75,9 +75,7 @@ def pretty_echo(dict_object: Dict, color: str = "white") -> None:
     """
     Given a dict-like object and a color, pretty click echo it.
     """
-    click.secho(
-        pprint.pformat(dict_object, indent=2, width=80, compact=True, depth=2), fg=color
-    )
+    click.secho(pprint.pformat(dict_object, indent=2, width=80, compact=True), fg=color)
 
 
 def handle_cli_response(
